@@ -52,6 +52,7 @@ AMPHORA_SUPPORTED_PROTOCOLS = [
     lib_consts.PROTOCOL_PROXY,
     lib_consts.PROTOCOL_PROXYV2,
     lib_consts.PROTOCOL_UDP,
+    lib_consts.PROTOCOL_SCTP,
 ]
 
 
@@ -83,11 +84,11 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
-    def _validate_alpn_protocols(self, listener):
-        if not listener.alpn_protocols:
+    def _validate_alpn_protocols(self, obj):
+        if not obj.alpn_protocols:
             return
         supported = consts.AMPHORA_SUPPORTED_ALPN_PROTOCOLS
-        not_supported = set(listener.alpn_protocols) - set(supported)
+        not_supported = set(obj.alpn_protocols) - set(supported)
         if not_supported:
             msg = ('Amphora provider does not support %s ALPN protocol(s). '
                    'Supported: %s'
@@ -196,6 +197,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
     # Pool
     def pool_create(self, pool):
         self._validate_pool_algorithm(pool)
+        self._validate_alpn_protocols(pool)
         payload = {consts.POOL_ID: pool.pool_id}
         self.client.cast({}, 'create_pool', **payload)
 
@@ -205,6 +207,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         self.client.cast({}, 'delete_pool', **payload)
 
     def pool_update(self, old_pool, new_pool):
+        self._validate_alpn_protocols(new_pool)
         if new_pool.lb_algorithm:
             self._validate_pool_algorithm(new_pool)
         pool_dict = new_pool.to_dict()
@@ -285,17 +288,14 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             if m.id not in new_member_ids:
                 deleted_members.append(m)
 
-        if deleted_members or new_members or updated_members:
-            payload = {'old_member_ids': [m.id for m in deleted_members],
-                       'new_member_ids': [m.member_id for m in new_members],
-                       'updated_members': updated_members}
-            self.client.cast({}, 'batch_update_members', **payload)
-        else:
-            LOG.info("Member batch update is a noop, returning early.")
+        payload = {'old_member_ids': [m.id for m in deleted_members],
+                   'new_member_ids': [m.member_id for m in new_members],
+                   'updated_members': updated_members}
+        self.client.cast({}, 'batch_update_members', **payload)
 
     def _validate_members(self, db_pool, members):
-        if db_pool.protocol == consts.PROTOCOL_UDP:
-            # For UDP LBs, check that we are not mixing IPv4 and IPv6
+        if db_pool.protocol in consts.LVS_PROTOCOLS:
+            # For SCTP/UDP LBs, check that we are not mixing IPv4 and IPv6
             for member in members:
                 member_is_ipv6 = utils.is_ipv6(member.address)
 
@@ -305,8 +305,8 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
                     if member_is_ipv6 != vip_is_ipv6:
                         msg = ("This provider doesn't support mixing IPv4 and "
-                               "IPv6 addresses for its VIP and members in UDP "
-                               "load balancers.")
+                               "IPv6 addresses for its VIP and members in {} "
+                               "load balancers.".format(db_pool.protocol))
                         raise exceptions.UnsupportedOptionError(
                             user_fault_string=msg,
                             operator_fault_string=msg)
