@@ -53,6 +53,7 @@ AMPHORA_SUPPORTED_PROTOCOLS = [
     lib_consts.PROTOCOL_PROXY,
     lib_consts.PROTOCOL_PROXYV2,
     lib_consts.PROTOCOL_UDP,
+    lib_consts.PROTOCOL_SCTP,
 ]
 
 
@@ -85,11 +86,11 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
-    def _validate_alpn_protocols(self, listener):
-        if not listener.alpn_protocols:
+    def _validate_alpn_protocols(self, obj):
+        if not obj.alpn_protocols:
             return
         supported = consts.AMPHORA_SUPPORTED_ALPN_PROTOCOLS
-        not_supported = set(listener.alpn_protocols) - set(supported)
+        not_supported = set(obj.alpn_protocols) - set(supported)
         if not_supported:
             msg = ('Amphora provider does not support %s ALPN protocol(s). '
                    'Supported: %s'
@@ -236,6 +237,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     def pool_create(self, pool):
         self._validate_pool_algorithm(pool)
+        self._validate_alpn_protocols(pool)
         payload = {consts.POOL: self._pool_convert_to_dict(pool)}
         self.client.cast({}, 'create_pool', **payload)
 
@@ -244,6 +246,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         self.client.cast({}, 'delete_pool', **payload)
 
     def pool_update(self, old_pool, new_pool):
+        self._validate_alpn_protocols(new_pool)
         if new_pool.lb_algorithm:
             self._validate_pool_algorithm(new_pool)
         pool_dict = self._pool_convert_to_dict(new_pool)
@@ -315,8 +318,8 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         self.client.cast({}, 'batch_update_members', **payload)
 
     def _validate_members(self, db_pool, members):
-        if db_pool.protocol == consts.PROTOCOL_UDP:
-            # For UDP LBs, check that we are not mixing IPv4 and IPv6
+        if db_pool.protocol in consts.LVS_PROTOCOLS:
+            # For SCTP/UDP LBs, check that we are not mixing IPv4 and IPv6
             for member in members:
                 member_is_ipv6 = utils.is_ipv6(member.address)
 
@@ -326,8 +329,8 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
                     if member_is_ipv6 != vip_is_ipv6:
                         msg = ("This provider doesn't support mixing IPv4 and "
-                               "IPv6 addresses for its VIP and members in UDP "
-                               "load balancers.")
+                               "IPv6 addresses for its VIP and members in {} "
+                               "load balancers.".format(db_pool.protocol))
                         raise exceptions.UnsupportedOptionError(
                             user_fault_string=msg,
                             operator_fault_string=msg)
