@@ -160,7 +160,11 @@ amphora_agent_opts = [
     cfg.StrOpt('agent_server_network_file',
                help=_("The file where the network interfaces are located. "
                       "Specifying this will override any value set for "
-                      "agent_server_network_dir.")),
+                      "agent_server_network_dir."),
+               deprecated_for_removal=True,
+               deprecated_reason=_('New amphora interface management '
+                                   'does not support single interface file.'),
+               deprecated_since='Xena'),
     cfg.IntOpt('agent_request_read_timeout', default=180,
                help=_("The time in seconds to allow a request from the "
                       "controller to run before terminating the socket.")),
@@ -609,7 +613,8 @@ certificate_opts = [
                default='publicURL',
                help='The endpoint_type to be used for barbican service.'),
     cfg.StrOpt('ca_certificates_file',
-               help=_('CA certificates file path')),
+               help=_('CA certificates file path for the key manager service '
+                      '(such as Barbican).')),
     cfg.BoolOpt('insecure',
                 default=False,
                 help=_('Disable certificate validation on SSL connections ')),
