@@ -17,10 +17,13 @@
 import datetime
 import re
 
+from oslo_log import log as logging
 from sqlalchemy.orm import collections
 
 from octavia.common import constants
 
+LOG = logging.getLogger(__name__)
+
 
 class BaseDataModel(object):
     def to_dict(self, calling_classes=None, recurse=False, **kwargs):
@@ -40,6 +43,9 @@ class BaseDataModel(object):
             if isinstance(value, datetime.datetime):
                 ret[attr] = value.isoformat()
                 continue
+            if isinstance(value, bytes):
+                ret[attr] = value.decode()
+                continue
             if recurse:
                 if isinstance(getattr(self, attr), list):
                     ret[attr] = []
@@ -287,7 +293,8 @@ class Pool(BaseDataModel):
                  created_at=None, updated_at=None, provisioning_status=None,
                  tags=None, tls_certificate_id=None,
                  ca_tls_certificate_id=None, crl_container_id=None,
-                 tls_enabled=None, tls_ciphers=None, tls_versions=None):
+                 tls_enabled=None, tls_ciphers=None, tls_versions=None,
+                 alpn_protocols=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -313,6 +320,7 @@ class Pool(BaseDataModel):
         self.tls_enabled = tls_enabled
         self.tls_ciphers = tls_ciphers
         self.tls_versions = tls_versions
+        self.alpn_protocols = alpn_protocols
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -339,7 +347,11 @@ class Pool(BaseDataModel):
                     break
         for pool in self.load_balancer.pools:
             if pool.id == self.id:
-                self.load_balancer.pools.remove(pool)
+                try:
+                    self.load_balancer.pools.remove(pool)
+                except ValueError:
+                    LOG.debug("Pool %s has already been removed from load "
+                              "balancer pools list.", pool.id)
                 break
         for l7policy in self.l7policies:
             if l7policy.redirect_pool_id == self.id:
