@@ -19,6 +19,7 @@ from novaclient import exceptions as nova_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from stevedore import driver as stevedore_driver
+import tenacity
 
 from octavia.common import clients
 from octavia.common import constants
@@ -31,47 +32,11 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-def _extract_amp_image_id_by_tag(client, image_tag, image_owner):
-    if image_owner:
-        images = list(client.images.list(
-            filters={'tag': [image_tag],
-                     'owner': image_owner,
-                     'status': constants.GLANCE_IMAGE_ACTIVE},
-            sort='created_at:desc',
-            limit=2))
-    else:
-        images = list(client.images.list(
-            filters={'tag': [image_tag],
-                     'status': constants.GLANCE_IMAGE_ACTIVE},
-            sort='created_at:desc',
-            limit=2))
-
-    if not images:
-        raise exceptions.GlanceNoTaggedImages(tag=image_tag)
-    image_id = images[0]['id']
-    num_images = len(images)
-    if num_images > 1:
-        LOG.warning("A single Glance image should be tagged with %(tag)s tag, "
-                    "but at least two were found. Using %(image_id)s.",
-                    {'tag': image_tag, 'image_id': image_id})
-    return image_id
-
-
-def _get_image_uuid(client, image_id, image_tag, image_owner):
-    if image_id:
-        if image_tag:
-            LOG.warning("Both amp_image_id and amp_image_tag options defined. "
-                        "Using the amp_image_id.")
-        return image_id
-
-    return _extract_amp_image_id_by_tag(client, image_tag, image_owner)
-
-
 class VirtualMachineManager(compute_base.ComputeBase):
     '''Compute implementation of virtual machines via nova.'''
 
     def __init__(self):
-        super(VirtualMachineManager, self).__init__()
+        super().__init__()
         # Must initialize nova api
         self._nova_client = clients.NovaAuth.get_nova_client(
             endpoint=CONF.nova.endpoint,
@@ -79,13 +44,6 @@ class VirtualMachineManager(compute_base.ComputeBase):
             endpoint_type=CONF.nova.endpoint_type,
             insecure=CONF.nova.insecure,
             cacert=CONF.nova.ca_certificates_file)
-        self._glance_client = clients.GlanceAuth.get_glance_client(
-            service_name=CONF.glance.service_name,
-            endpoint=CONF.glance.endpoint,
-            region=CONF.glance.region_name,
-            endpoint_type=CONF.glance.endpoint_type,
-            insecure=CONF.glance.insecure,
-            cacert=CONF.glance.ca_certificates_file)
         self.manager = self._nova_client.servers
         self.server_groups = self._nova_client.server_groups
         self.flavor_manager = self._nova_client.flavors
@@ -95,17 +53,20 @@ class VirtualMachineManager(compute_base.ComputeBase):
             name=CONF.controller_worker.volume_driver,
             invoke_on_load=True
         ).driver
+        self.image_driver = stevedore_driver.DriverManager(
+            namespace='octavia.image.drivers',
+            name=CONF.controller_worker.image_driver,
+            invoke_on_load=True
+        ).driver
 
     def build(self, name="amphora_name", amphora_flavor=None,
-              image_id=None, image_tag=None, image_owner=None,
-              key_name=None, sec_groups=None, network_ids=None,
-              port_ids=None, config_drive_files=None, user_data=None,
-              server_group_id=None, availability_zone=None):
+              image_tag=None, image_owner=None, key_name=None, sec_groups=None,
+              network_ids=None, port_ids=None, config_drive_files=None,
+              user_data=None, server_group_id=None, availability_zone=None):
         '''Create a new virtual machine.
 
         :param name: optional name for amphora
         :param amphora_flavor: image flavor for virtual machine
-        :param image_id: image ID for virtual machine
         :param image_tag: image tag for virtual machine
         :param key_name: keypair to add to the virtual machine
         :param sec_groups: Security group IDs for virtual machine
@@ -144,8 +105,8 @@ class VirtualMachineManager(compute_base.ComputeBase):
                 "group": server_group_id}
             az_name = availability_zone or CONF.nova.availability_zone
 
-            image_id = _get_image_uuid(
-                self._glance_client, image_id, image_tag, image_owner)
+            image_id = self.image_driver.get_image_id_by_tag(
+                image_tag, image_owner)
 
             if CONF.nova.random_amphora_name_length:
                 r = random.SystemRandom()
@@ -214,11 +175,19 @@ class VirtualMachineManager(compute_base.ComputeBase):
             amphora, fault = self.get_amphora(compute_id)
             if amphora and amphora.status == 'ACTIVE':
                 return constants.UP
-        except Exception:
+        except Exception as e:
             LOG.exception("Error retrieving nova virtual machine status.")
-            raise exceptions.ComputeStatusException()
+            raise exceptions.ComputeStatusException() from e
         return constants.DOWN
 
+    def _raise_compute_exception(self):
+        LOG.exception("Error retrieving nova virtual machine.")
+        raise exceptions.ComputeGetException()
+
+    @tenacity.retry(retry=tenacity.retry_if_exception_type(),
+                    stop=tenacity.stop_after_attempt(CONF.compute.max_retries),
+                    retry_error_callback=_raise_compute_exception,
+                    wait=tenacity.wait_fixed(CONF.compute.retry_interval))
     def get_amphora(self, compute_id, management_network_id=None):
         '''Retrieve the information in nova of a virtual machine.
 
@@ -228,11 +197,7 @@ class VirtualMachineManager(compute_base.ComputeBase):
         :returns: fault message or None
         '''
         # utilize nova client ServerManager 'get' method to retrieve info
-        try:
-            amphora = self.manager.get(compute_id)
-        except Exception:
-            LOG.exception("Error retrieving nova virtual machine.")
-            raise exceptions.ComputeGetException()
+        amphora = self.manager.get(compute_id)
         return self._translate_amphora(amphora, management_network_id)
 
     def _translate_amphora(self, nova_response, management_network_id=None):
@@ -320,9 +285,9 @@ class VirtualMachineManager(compute_base.ComputeBase):
         try:
             server_group_obj = self.server_groups.create(**kwargs)
             return server_group_obj
-        except Exception:
+        except Exception as e:
             LOG.exception("Error create server group instance.")
-            raise exceptions.ServerGroupObjectCreateException()
+            raise exceptions.ServerGroupObjectCreateException() from e
 
     def delete_server_group(self, server_group_id):
         """Delete a server group object
@@ -336,9 +301,9 @@ class VirtualMachineManager(compute_base.ComputeBase):
         except nova_exceptions.NotFound:
             LOG.warning("Server group instance with id: %s not found. "
                         "Assuming already deleted.", server_group_id)
-        except Exception:
+        except Exception as e:
             LOG.exception("Error delete server group instance.")
-            raise exceptions.ServerGroupObjectDeleteException()
+            raise exceptions.ServerGroupObjectDeleteException() from e
 
     def attach_network_or_port(self, compute_id, network_id=None,
                                ip_address=None, port_id=None):
@@ -422,10 +387,10 @@ class VirtualMachineManager(compute_base.ComputeBase):
         """
         try:
             self.flavor_manager.get(flavor_id)
-        except nova_exceptions.NotFound:
+        except nova_exceptions.NotFound as e:
             LOG.info('Flavor %s was not found in nova.', flavor_id)
             raise exceptions.InvalidSubresource(resource='Nova flavor',
-                                                id=flavor_id)
+                                                id=flavor_id) from e
         except Exception as e:
             LOG.exception('Nova reports a failure getting flavor details for '
                           'flavor ID %s: %s', flavor_id, str(e))
