@@ -69,7 +69,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         self._flavor_repo = repo.FlavorRepository()
         self._az_repo = repo.AvailabilityZoneRepository()
 
-        super(ControllerWorker, self).__init__()
+        super().__init__()
 
     @tenacity.retry(
         retry=(
@@ -102,7 +102,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                 store[constants.AVAILABILITY_ZONE] = (
                     self._az_repo.get_availability_zone_metadata_dict(
                         db_apis.get_session(), availability_zone))
-            create_amp_tf = self._taskflow_load(
+            create_amp_tf = self.taskflow_load(
                 self._amphora_flows.get_create_amphora_flow(),
                 store=store)
             with tf_logging.DynamicLoggingListener(create_amp_tf, log=LOG):
@@ -111,6 +111,27 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             return create_amp_tf.storage.fetch('amphora')
         except Exception as e:
             LOG.error('Failed to create an amphora due to: %s', str(e))
+        return None
+
+    def delete_amphora(self, amphora_id):
+        """Deletes an existing Amphora.
+
+        :param amphora_id: ID of the amphora to delete
+        :returns: None
+        :raises AmphoraNotFound: The referenced Amphora was not found
+        """
+        try:
+            amphora = self._amphora_repo.get(db_apis.get_session(),
+                                             id=amphora_id)
+            delete_amp_tf = self.taskflow_load(
+                self._amphora_flows.get_delete_amphora_flow(amphora))
+            with tf_logging.DynamicLoggingListener(delete_amp_tf, log=LOG):
+                delete_amp_tf.run()
+        except Exception as e:
+            LOG.error('Failed to delete a amphora %s due to: %s',
+                      amphora_id, str(e))
+            return
+        LOG.info('Finished deleting amphora %s.', amphora_id)
 
     @tenacity.retry(
         retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
@@ -139,7 +160,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         pool.health_monitor = health_mon
         load_balancer = pool.load_balancer
 
-        create_hm_tf = self._taskflow_load(
+        create_hm_tf = self.taskflow_load(
             self._health_monitor_flows.get_create_health_monitor_flow(),
             store={constants.HEALTH_MON: health_mon,
                    constants.POOL: pool,
@@ -163,7 +184,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = pool.listeners
         load_balancer = pool.load_balancer
 
-        delete_hm_tf = self._taskflow_load(
+        delete_hm_tf = self.taskflow_load(
             self._health_monitor_flows.get_delete_health_monitor_flow(),
             store={constants.HEALTH_MON: health_mon,
                    constants.POOL: pool,
@@ -198,7 +219,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         pool.health_monitor = health_mon
         load_balancer = pool.load_balancer
 
-        update_hm_tf = self._taskflow_load(
+        update_hm_tf = self.taskflow_load(
             self._health_monitor_flows.get_update_health_monitor_flow(),
             store={constants.HEALTH_MON: health_mon,
                    constants.POOL: pool,
@@ -234,12 +255,12 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         load_balancer = listener.load_balancer
         listeners = load_balancer.listeners
 
-        create_listener_tf = self._taskflow_load(self._listener_flows.
-                                                 get_create_listener_flow(),
-                                                 store={constants.LOADBALANCER:
-                                                        load_balancer,
-                                                        constants.LISTENERS:
-                                                            listeners})
+        create_listener_tf = self.taskflow_load(self._listener_flows.
+                                                get_create_listener_flow(),
+                                                store={constants.LOADBALANCER:
+                                                       load_balancer,
+                                                       constants.LISTENERS:
+                                                           listeners})
         with tf_logging.DynamicLoggingListener(create_listener_tf,
                                                log=LOG):
             create_listener_tf.run()
@@ -255,7 +276,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                                            id=listener_id)
         load_balancer = listener.load_balancer
 
-        delete_listener_tf = self._taskflow_load(
+        delete_listener_tf = self.taskflow_load(
             self._listener_flows.get_delete_listener_flow(),
             store={constants.LOADBALANCER: load_balancer,
                    constants.LISTENER: listener})
@@ -285,16 +306,16 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
 
         load_balancer = listener.load_balancer
 
-        update_listener_tf = self._taskflow_load(self._listener_flows.
-                                                 get_update_listener_flow(),
-                                                 store={constants.LISTENER:
-                                                        listener,
-                                                        constants.LOADBALANCER:
-                                                            load_balancer,
-                                                        constants.UPDATE_DICT:
-                                                            listener_updates,
-                                                        constants.LISTENERS:
-                                                            [listener]})
+        update_listener_tf = self.taskflow_load(self._listener_flows.
+                                                get_update_listener_flow(),
+                                                store={constants.LISTENER:
+                                                       listener,
+                                                       constants.LOADBALANCER:
+                                                           load_balancer,
+                                                       constants.UPDATE_DICT:
+                                                           listener_updates,
+                                                       constants.LISTENERS:
+                                                           [listener]})
         with tf_logging.DynamicLoggingListener(update_listener_tf, log=LOG):
             update_listener_tf.run()
 
@@ -345,7 +366,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         create_lb_flow = self._lb_flows.get_create_load_balancer_flow(
             topology=topology, listeners=lb.listeners)
 
-        create_lb_tf = self._taskflow_load(create_lb_flow, store=store)
+        create_lb_tf = self.taskflow_load(create_lb_flow, store=store)
         with tf_logging.DynamicLoggingListener(create_lb_tf, log=LOG):
             create_lb_tf.run()
 
@@ -366,7 +387,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             (flow, store) = self._lb_flows.get_delete_load_balancer_flow(lb)
         store.update({constants.LOADBALANCER: lb,
                       constants.SERVER_GROUP_ID: lb.server_group_id})
-        delete_lb_tf = self._taskflow_load(flow, store=store)
+        delete_lb_tf = self.taskflow_load(flow, store=store)
 
         with tf_logging.DynamicLoggingListener(delete_lb_tf,
                                                log=LOG):
@@ -396,7 +417,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             db_apis.get_session(),
             load_balancer_id=load_balancer_id)
 
-        update_lb_tf = self._taskflow_load(
+        update_lb_tf = self.taskflow_load(
             self._lb_flows.get_update_load_balancer_flow(),
             store={constants.LOADBALANCER: lb,
                    constants.LISTENERS: listeners,
@@ -444,7 +465,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         else:
             store[constants.AVAILABILITY_ZONE] = {}
 
-        create_member_tf = self._taskflow_load(
+        create_member_tf = self.taskflow_load(
             self._member_flows.get_create_member_flow(),
             store=store)
         with tf_logging.DynamicLoggingListener(create_member_tf,
@@ -476,7 +497,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         else:
             store[constants.AVAILABILITY_ZONE] = {}
 
-        delete_member_tf = self._taskflow_load(
+        delete_member_tf = self.taskflow_load(
             self._member_flows.get_delete_member_flow(),
             store=store
         )
@@ -527,7 +548,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         else:
             store[constants.AVAILABILITY_ZONE] = {}
 
-        batch_update_members_tf = self._taskflow_load(
+        batch_update_members_tf = self.taskflow_load(
             self._member_flows.get_batch_update_members_flow(
                 old_members, new_members, updated_members),
             store=store)
@@ -571,7 +592,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         else:
             store[constants.AVAILABILITY_ZONE] = {}
 
-        update_member_tf = self._taskflow_load(
+        update_member_tf = self.taskflow_load(
             self._member_flows.get_update_member_flow(),
             store=store)
         with tf_logging.DynamicLoggingListener(update_member_tf,
@@ -603,13 +624,13 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = pool.listeners
         load_balancer = pool.load_balancer
 
-        create_pool_tf = self._taskflow_load(self._pool_flows.
-                                             get_create_pool_flow(),
-                                             store={constants.POOL: pool,
-                                                    constants.LISTENERS:
-                                                        listeners,
-                                                    constants.LOADBALANCER:
-                                                        load_balancer})
+        create_pool_tf = self.taskflow_load(self._pool_flows.
+                                            get_create_pool_flow(),
+                                            store={constants.POOL: pool,
+                                                   constants.LISTENERS:
+                                                       listeners,
+                                                   constants.LOADBALANCER:
+                                                       load_balancer})
         with tf_logging.DynamicLoggingListener(create_pool_tf,
                                                log=LOG):
             create_pool_tf.run()
@@ -627,7 +648,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         load_balancer = pool.load_balancer
         listeners = pool.listeners
 
-        delete_pool_tf = self._taskflow_load(
+        delete_pool_tf = self.taskflow_load(
             self._pool_flows.get_delete_pool_flow(),
             store={constants.POOL: pool, constants.LISTENERS: listeners,
                    constants.LOADBALANCER: load_balancer})
@@ -658,15 +679,15 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = pool.listeners
         load_balancer = pool.load_balancer
 
-        update_pool_tf = self._taskflow_load(self._pool_flows.
-                                             get_update_pool_flow(),
-                                             store={constants.POOL: pool,
-                                                    constants.LISTENERS:
-                                                        listeners,
-                                                    constants.LOADBALANCER:
-                                                        load_balancer,
-                                                    constants.UPDATE_DICT:
-                                                        pool_updates})
+        update_pool_tf = self.taskflow_load(self._pool_flows.
+                                            get_update_pool_flow(),
+                                            store={constants.POOL: pool,
+                                                   constants.LISTENERS:
+                                                       listeners,
+                                                   constants.LOADBALANCER:
+                                                       load_balancer,
+                                                   constants.UPDATE_DICT:
+                                                       pool_updates})
         with tf_logging.DynamicLoggingListener(update_pool_tf,
                                                log=LOG):
             update_pool_tf.run()
@@ -696,7 +717,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
 
-        create_l7policy_tf = self._taskflow_load(
+        create_l7policy_tf = self.taskflow_load(
             self._l7policy_flows.get_create_l7policy_flow(),
             store={constants.L7POLICY: l7policy,
                    constants.LISTENERS: listeners,
@@ -718,7 +739,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         load_balancer = l7policy.listener.load_balancer
         listeners = [l7policy.listener]
 
-        delete_l7policy_tf = self._taskflow_load(
+        delete_l7policy_tf = self.taskflow_load(
             self._l7policy_flows.get_delete_l7policy_flow(),
             store={constants.L7POLICY: l7policy,
                    constants.LISTENERS: listeners,
@@ -750,7 +771,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
 
-        update_l7policy_tf = self._taskflow_load(
+        update_l7policy_tf = self.taskflow_load(
             self._l7policy_flows.get_update_l7policy_flow(),
             store={constants.L7POLICY: l7policy,
                    constants.LISTENERS: listeners,
@@ -786,7 +807,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
 
-        create_l7rule_tf = self._taskflow_load(
+        create_l7rule_tf = self.taskflow_load(
             self._l7rule_flows.get_create_l7rule_flow(),
             store={constants.L7RULE: l7rule,
                    constants.L7POLICY: l7policy,
@@ -809,7 +830,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         load_balancer = l7policy.listener.load_balancer
         listeners = [l7policy.listener]
 
-        delete_l7rule_tf = self._taskflow_load(
+        delete_l7rule_tf = self.taskflow_load(
             self._l7rule_flows.get_delete_l7rule_flow(),
             store={constants.L7RULE: l7rule,
                    constants.L7POLICY: l7policy,
@@ -843,7 +864,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         listeners = [l7policy.listener]
         load_balancer = l7policy.listener.load_balancer
 
-        update_l7rule_tf = self._taskflow_load(
+        update_l7rule_tf = self.taskflow_load(
             self._l7rule_flows.get_update_l7rule_flow(),
             store={constants.L7RULE: l7rule,
                    constants.L7POLICY: l7policy,
@@ -854,13 +875,14 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                                                log=LOG):
             update_l7rule_tf.run()
 
-    def failover_amphora(self, amphora_id):
+    def failover_amphora(self, amphora_id, reraise=False):
         """Perform failover operations for an amphora.
 
         Note: This expects the load balancer to already be in
         provisioning_status=PENDING_UPDATE state.
 
         :param amphora_id: ID for amphora to failover
+        :param reraise: If enabled reraise any caught exception
         :returns: None
         :raises octavia.common.exceptions.NotFound: The referenced amphora was
                                                     not found
@@ -933,8 +955,8 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                              constants.LOADBALANCER_ID: lb_id,
                              constants.VIP: vip}
 
-            failover_amphora_tf = self._taskflow_load(amp_failover_flow,
-                                                      store=stored_params)
+            failover_amphora_tf = self.taskflow_load(amp_failover_flow,
+                                                     store=stored_params)
 
             with tf_logging.DynamicLoggingListener(failover_amphora_tf,
                                                    log=LOG):
@@ -948,7 +970,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
                       "role": amphora.role})
 
         except Exception as e:
-            with excutils.save_and_reraise_exception(reraise=False):
+            with excutils.save_and_reraise_exception(reraise=reraise):
                 LOG.exception("Amphora %s failover exception: %s",
                               amphora_id, str(e))
                 self._amphora_repo.update(db_apis.get_session(),
@@ -1084,8 +1106,8 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             else:
                 stored_params[constants.AVAILABILITY_ZONE] = {}
 
-            failover_lb_tf = self._taskflow_load(lb_failover_flow,
-                                                 store=stored_params)
+            failover_lb_tf = self.taskflow_load(lb_failover_flow,
+                                                store=stored_params)
 
             with tf_logging.DynamicLoggingListener(failover_lb_tf, log=LOG):
                 failover_lb_tf.run()
@@ -1113,7 +1135,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
         LOG.info("Start amphora cert rotation, amphora's id is: %s",
                  amphora_id)
 
-        certrotation_amphora_tf = self._taskflow_load(
+        certrotation_amphora_tf = self.taskflow_load(
             self._amphora_flows.cert_rotate_amphora_flow(),
             store={constants.AMPHORA: amp,
                    constants.AMPHORA_ID: amp.id})
@@ -1144,7 +1166,7 @@ class ControllerWorker(base_taskflow.BaseTaskFlowEngine):
             flavor = self._flavor_repo.get_flavor_metadata_dict(
                 db_apis.get_session(), lb.flavor_id)
 
-        update_amphora_tf = self._taskflow_load(
+        update_amphora_tf = self.taskflow_load(
             self._amphora_flows.update_amphora_config_flow(),
             store={constants.AMPHORA: amp,
                    constants.FLAVOR: flavor})
