@@ -33,7 +33,7 @@ AUTH_VERSION = '2'
 class TestAmphoraFlows(base.TestCase):
 
     def setUp(self):
-        super(TestAmphoraFlows, self).setUp()
+        super().setUp()
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         self.conf.config(
             group="controller_worker",
@@ -362,10 +362,11 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+        self.assertIn(constants.LOADBALANCER, amp_flow.requires)
 
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(1, len(amp_flow.requires))
+        self.assertEqual(2, len(amp_flow.requires))
         self.assertEqual(1, len(amp_flow.provides))
 
     def test_get_failover_flow_spare(self, mock_get_net_driver):
@@ -376,10 +377,11 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIsInstance(amp_flow, flow.Flow)
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
+        self.assertIn(constants.LOADBALANCER, amp_flow.requires)
 
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
-        self.assertEqual(1, len(amp_flow.requires))
+        self.assertEqual(2, len(amp_flow.requires))
         self.assertEqual(1, len(amp_flow.provides))
 
     def test_cert_rotate_amphora_flow(self, mock_get_net_driver):
